@@ -1,6 +1,5 @@
 from arkdriver.driver import Admin, Application, Driver
-from arkdriver.server import GameBotServer
 from arkdriver.main import run
 from arkdriver.lib import console
 
-__all__ = ['Admin', "run", 'console', 'GameBotServer', 'Application', 'Driver']
+__all__ = ['Admin', "run", 'console', 'Application', 'Driver']
